==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkThreadedSynchronizedTemplatesCutter3D.java <==
// java wrapper for vtkThreadedSynchronizedTemplatesCutter3D object
//

package vtk;
import vtk.*;

public class vtkThreadedSynchronizedTemplatesCutter3D extends vtkThreadedSynchronizedTemplates3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ThreadedExecute_2(vtkImageData id0,vtkInformation id1,int id2);
  public void ThreadedExecute(vtkImageData id0,vtkInformation id1,int id2)
    { ThreadedExecute_2(id0,id1,id2); }

  private native void SetCutFunction_3(vtkImplicitFunction id0);
  public void SetCutFunction(vtkImplicitFunction id0)
    { SetCutFunction_3(id0); }

  private native long GetCutFunction_4();
  public vtkImplicitFunction GetCutFunction() {
    long temp = GetCutFunction_4();

    if (temp == 0) return null;
    return (vtkImplicitFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutputPointsPrecision_5(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_5(id0); }

  private native int GetOutputPointsPrecisionMinValue_6();
  public int GetOutputPointsPrecisionMinValue()
    { return GetOutputPointsPrecisionMinValue_6(); }

  private native int GetOutputPointsPrecisionMaxValue_7();
  public int GetOutputPointsPrecisionMaxValue()
    { return GetOutputPointsPrecisionMaxValue_7(); }

  private native int GetOutputPointsPrecision_8();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_8(); }

  private native int GetMTime_9();
  public int GetMTime()
    { return GetMTime_9(); }

  public vtkThreadedSynchronizedTemplatesCutter3D() { super(); }

  public vtkThreadedSynchronizedTemplatesCutter3D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkThreadedSynchronizedTemplatesCutter3D.java <==
// java wrapper for vtkThreadedSynchronizedTemplatesCutter3D object
//

package vtk;
import vtk.*;

public class vtkThreadedSynchronizedTemplatesCutter3D extends vtkThreadedSynchronizedTemplates3D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ThreadedExecute_2(vtkImageData id0,vtkInformation id1,int id2);
  public void ThreadedExecute(vtkImageData id0,vtkInformation id1,int id2)
    { ThreadedExecute_2(id0,id1,id2); }

  private native void SetCutFunction_3(vtkImplicitFunction id0);
  public void SetCutFunction(vtkImplicitFunction id0)
    { SetCutFunction_3(id0); }

  private native long GetCutFunction_4();
  public vtkImplicitFunction GetCutFunction() {
    long temp = GetCutFunction_4();

    if (temp == 0) return null;
    return (vtkImplicitFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutputPointsPrecision_5(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_5(id0); }

  private native int GetOutputPointsPrecisionMinValue_6();
  public int GetOutputPointsPrecisionMinValue()
    { return GetOutputPointsPrecisionMinValue_6(); }

  private native int GetOutputPointsPrecisionMaxValue_7();
  public int GetOutputPointsPrecisionMaxValue()
    { return GetOutputPointsPrecisionMaxValue_7(); }

  private native int GetOutputPointsPrecision_8();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_8(); }

  private native int GetMTime_9();
  public int GetMTime()
    { return GetMTime_9(); }

  public vtkThreadedSynchronizedTemplatesCutter3D() { super(); }

  public vtkThreadedSynchronizedTemplatesCutter3D(long id) { super(id); }
  public native long   VTKInit();

}
